@@ -1,17 +1,29 @@
 #' @include disequilibrium_model.R
 
-#' @title Basic disequilibrium model with unknown sample separation.
+#' @describeIn market_models Basic disequilibrium model with unknown sample separation.
 #'
-#' @description The basic disequilibrium model consists of three equations. Two of them are
-#' the demand and supply equations. In addition, the model replaces the market clearing condition
-#' with the short side rule. The model is estimated using full information maximum likelihood.
+#' @description
+#' \subsection{diseq_basic}{
+#' The basic disequilibrium model consists of three equations. Two of them
+#' are the demand and supply equations. In addition, the model replaces the market
+#' clearing condition with the short side rule. The model is estimated using full
+#' information maximum likelihood.
 #'
 #' \deqn{D_{nt} = X_{d,nt}'\beta_{d} + u_{d,nt},}
 #' \deqn{S_{nt} = X_{s,nt}'\beta_{s} + u_{s,nt},}
 #' \deqn{Q_{nt} = \min\{D_{nt},S_{nt}\}.}
-#'
+#' }
+#' @export
+setClass(
+  "diseq_basic",
+  contains = "disequilibrium_model",
+  representation(),
+  prototype()
+)
+
+#' @describeIn initialize_market_model Basic disequilibrium model base constructor
 #' @examples
-#' simulated_data <- simulate_model_data(
+#' simulated_data <- simulate_data(
 #'   "diseq_basic", 500, 3, # model type, observed entities, observed time points
 #'   -0.9, 8.9, c(0.3, -0.2), c(-0.03, -0.01), # demand coefficients
 #'   0.9, 4.2, c(0.03), c(-0.05, 0.02) # supply coefficients
@@ -23,17 +35,10 @@
 #'   c("id", "date"), "Q", "P", # keys, quantity, and price variables
 #'   "P + Xd1 + Xd2 + X1 + X2", "P + Xs1 + X1 + X2", # equation specifications
 #'   simulated_data, # data
-#'   correlated_shocks = TRUE # allow shocks to be correlated
+#'   correlated_shocks = FALSE # use independent shocks
 #' )
-#' @export
-setClass(
-  "diseq_basic",
-  contains = "disequilibrium_model",
-  representation(),
-  prototype()
-)
-
-#' @describeIn initialize_market_model Basic disequilibrium model base constructor
+#'
+#' show(model)
 setMethod(
   "initialize", "diseq_basic",
   function(.Object,
@@ -56,11 +61,13 @@ setMethod(
 )
 
 #' @rdname minus_log_likelihood
-setMethod("minus_log_likelihood", signature(object = "diseq_basic"), function(object, parameters) {
+setMethod("minus_log_likelihood", signature(object = "diseq_basic"),
+          function(object, parameters) {
   object@system <- set_parameters(object@system, parameters)
   -sum(log(object@system@lh))
 })
 
+#' @rdname gradient
 setMethod("gradient", signature(object = "diseq_basic"), function(object, parameters) {
   object@system <- set_parameters(object@system, parameters)
   -colSums(calculate_system_scores(object@system))
