@@ -1,6 +1,11 @@
 #' @include equation_base.R
 
-#' @title Basic disequilibrium model equation class
+#' @describeIn equation_classes Basic disequilibrium model equation class
+#'
+#' @slot h \deqn{h_{x} = \frac{x - \mathrm{E} x}{\sqrt{\mathrm{Var} x}}}
+#' @slot z \deqn{z_{xy} = \frac{h_{x} - \rho_{xy}h_{y}}{\sqrt{1 - \rho_{xy}^2}}}
+#' @slot psi \deqn{\psi_{x} = \phi(h_{x})}
+#' @slot Psi \deqn{\Psi_{x} = 1 - \Phi(z_{xy})}
 setClass(
   "equation_basic",
   contains = "equation_base",
@@ -26,6 +31,9 @@ setMethod(
   }
 )
 
-setMethod("set_parameters", signature(object = "equation_basic"), function(object, parameters) {
-  object <- callNextMethod(object, parameters)
-})
+setMethod(
+  "set_parameters", signature(object = "equation_basic"),
+  function(object, parameters) {
+    object <- callNextMethod(object, parameters)
+  }
+)
