@@ -1,4 +1,25 @@
 #' @include equation_base.R
+
+#' @title System classes
+#'
+#' @details Classes with data and functionality describing systems of models.
+#' @name system_classes
+NULL
+
+#' @describeIn system_classes System base class
+#' @slot demand Demand equation.
+#' @slot supply Supply equation.
+#' @slot correlated_shocks Boolean indicating whether the shock of the equations of the
+#' system are correlated.
+#' @slot sample_separation Boolean indicating whether the sample of the system is
+#' separated.
+#' @slot quantity_variable The name of the quantity variable of the system.
+#' @slot price_variable The name of the price variable of the system.
+#' @slot quantity_vector A vector with the system's observed quantities.
+#' @slot price_vector A vector with the system's observed prices.
+#' @slot rho Correlation coefficient of demand and supply shocks.
+#' @slot rho1 \deqn{\rho_{1} = \frac{1}{\sqrt{1 - \rho}}}
+#' @slot rho2 \deqn{\rho_{2} = \rho\rho_{1}}
 setClass(
   "system_base",
   representation(
@@ -86,10 +107,18 @@ setMethod("summary_implementation", signature(object = "system_base"), function(
   cat(sprintf("  %-18s: %s\n", "Price Var", object@price_variable))
 })
 
+#' @describeIn variable_names Lagged price variable name.
+#' @description \code{lagged_price_variable}: The lagged price variable name is
+#' constructed by concatenating \code{LAGGED} with the price variable name.
+#' @export
 setGeneric("lagged_price_variable", function(object) {
   standardGeneric("lagged_price_variable")
 })
 
+#' @describeIn variable_names Price differences variable name.
+#' @description \code{price_differences_variable}: The price difference variable name is
+#' constructed by concatenating the price variable name with \code{DIFF}.
+#' @export
 setGeneric("price_differences_variable", function(object) {
   standardGeneric("price_differences_variable")
 })
@@ -122,13 +151,18 @@ setGeneric("calculate_system_scores", function(object) {
   standardGeneric("calculate_system_scores")
 })
 
+#' @rdname variable_names
 setMethod("lagged_price_variable", signature(object = "system_base"), function(object) {
   paste0("LAGGED_", object@demand@price_variable)
 })
 
-setMethod("price_differences_variable", signature(object = "system_base"), function(object) {
-  paste0(object@price_variable, "_DIFF")
-})
+#' @rdname variable_names
+setMethod(
+  "price_differences_variable", signature(object = "system_base"),
+  function(object) {
+    paste0(object@price_variable, "_DIFF")
+  }
+)
 
 setMethod("correlation_variable", signature(object = "system_base"), function(object) {
   "RHO"
@@ -155,15 +189,17 @@ setMethod("likelihood_variables", signature(object = "system_base"), function(ob
   likelihood_variables
 })
 
-
-setMethod("set_parameters", signature(object = "system_base"), function(object, parameters) {
-  object@demand <- set_parameters(object@demand, parameters)
-  object@supply <- set_parameters(object@supply, parameters)
-  if (object@correlated_shocks) {
-    object@rho <- parameters[correlation_variable(object)]
-    object@rho <- ifelse(abs(object@rho) > 1, NA_real_, object@rho)
-    object@rho1 <- 1 / sqrt(1 - object@rho**2)
-    object@rho2 <- object@rho * object@rho1
+setMethod(
+  "set_parameters", signature(object = "system_base"),
+  function(object, parameters) {
+    object@demand <- set_parameters(object@demand, parameters)
+    object@supply <- set_parameters(object@supply, parameters)
+    if (object@correlated_shocks) {
+      object@rho <- parameters[correlation_variable(object)]
+      object@rho <- ifelse(abs(object@rho) > 1, NA_real_, object@rho)
+      object@rho1 <- 1 / sqrt(1 - object@rho**2)
+      object@rho2 <- object@rho * object@rho1
+    }
+    object
   }
-  object
-})
+)
