@@ -22,7 +22,7 @@ test_that(paste0("Model can be simulated"), {
 })
 
 est <- NULL
-test_that(paste0(model_description(mdl), " can be estimated"), {
+test_that(paste0(model_name(mdl), " can be estimated"), {
   est <<- estimate(mdl,
     control = optimization_control, method = optimization_method,
     standard_errors = c("id")
@@ -30,15 +30,15 @@ test_that(paste0(model_description(mdl), " can be estimated"), {
   expect_is(est, "mle2")
 })
 
-test_that(paste0("Estimates of '", model_description(mdl), "' are accurate"), {
+test_that(paste0("Estimates of '", model_name(mdl), "' are accurate"), {
   test_estimation_accuracy(est@coef, unlist(parameters[-c(1, 2)]), 1e-0)
 })
 
 test_that(paste0("Marginal effect can be calculated"), {
-  test_marginal_effect(mean_marginal_effect, mdl, est, "P")
-  test_marginal_effect(mean_marginal_effect, mdl, est, "Xs1")
-  test_marginal_effect(marginal_effect_at_mean, mdl, est, "P")
-  test_marginal_effect(marginal_effect_at_mean, mdl, est, "Xs1")
+  test_marginal_effect(shortage_probability_marginal, mdl, est, "P", "mean")
+  test_marginal_effect(shortage_probability_marginal, mdl, est, "Xs1", "mean")
+  test_marginal_effect(shortage_probability_marginal, mdl, est, "P", "at_the_mean")
+  test_marginal_effect(shortage_probability_marginal, mdl, est, "Xs1", "at_the_mean")
 })
 
 test_that(paste0("Aggregation can be calculated"), {
@@ -56,7 +56,7 @@ test_that(paste0("Scores can be calculated"), {
 })
 
 test_that(paste0(
-  "Calculated gradient of '", model_description(mdl),
+  "Calculated gradient of '", model_name(mdl),
   "' matches the numerical approximation"
 ), {
   test_calculated_gradient(mdl, est@coef, 1e-4)
@@ -65,7 +65,7 @@ test_that(paste0(
 skip_on_cran()
 
 test_that(paste0(
-  "Calculated hessian of '", model_description(mdl),
+  "Calculated hessian of '", model_name(mdl),
   "' matches the numerical approximation"
 ), {
   test_calculated_hessian(mdl, est@coef, 1e-4)
